@@ -7,7 +7,7 @@ import subprocess
 
 from pydmt.utils.filesystem import unlink_files, mkdir_touch
 
-from pydmt.builders.one_source_one_target import OneSourceOneTarget
+from pydmt.api.one_source_one_target import OneSourceOneTarget
 
 
 class Installer(OneSourceOneTarget):
